# Rovisen Sentinel API

Works through the Copernicus Data Space Ecosystem.

Some functionalities, such as Sentinel 2 Cog access and download, depends on AWS credentials loaded in your environment

## Developer Setup

To develop this API, configure user and place the credentials inside a `.env` file at the root following the `.env.copy` template.
